| Copyright | (c) Ivan A. Malison |
|---|---|
| License | BSD3-style (see LICENSE) |
| Maintainer | Ivan A. Malison |
| Stability | unstable |
| Portability | unportable |
| Safe Haskell | None |
| Language | Haskell2010 |
System.Taffybar.ToggleMonitor
Description
This module provides a dbus interface that allows users to toggle the display of taffybar on each monitor while it is running.
Documentation
toggleableMonitors :: MVar (Map Int Bool) -> TaffybarConfigEQ -> IO (Int -> Maybe TaffybarConfigEQ) Source #
withToggleSupport :: TaffybarConfig -> IO () Source #