taffybar
Copyright(c) Ivan Malison
LicenseBSD3-style (see LICENSE)
MaintainerIvan Malison <IvanMalison@gmail.com>
Stabilityunstable
Portabilityunportable
Safe HaskellNone
LanguageHaskell2010

System.Taffybar.Widget.Layout

Contents

Description

Simple text widget that shows the XMonad layout used in the currently active workspace, and that allows to change it by clicking with the mouse: left-click to switch to the next layout in the list, right-click to switch to the first one (as configured in xmonad.hs)

Synopsis

Usage

This widget requires that the XMonad.Hooks.TaffybarPagerHints hook be installed in your xmonad.hs:

import XMonad.Hooks.TaffybarPagerHints (pagerHints)
main = do
  xmonad $ ewmh $ pagerHints $ defaultConfig
...

Once you've properly configured xmonad.hs, you can use the widget in your taffybar.hs file:

import System.Taffybar.Widget.Layout
main = do
  let los = layoutSwitcherNew def

now you can use los as any other Taffybar widget.

newtype LayoutConfig Source #

Constructors

LayoutConfig 

Instances

Instances details
Default LayoutConfig Source # 
Instance details

Defined in System.Taffybar.Widget.Layout

Methods

def :: LayoutConfig #

layoutNew :: LayoutConfig -> TaffyIO Widget Source #

Create a new Layout widget that will use the given Pager as its source of events.