| Copyright | (c) Ivan A. Malison |
|---|---|
| License | BSD3-style (see LICENSE) |
| Maintainer | Ivan A. Malison |
| Stability | unstable |
| Portability | unportable |
| Safe Haskell | None |
| Language | Haskell2010 |
System.Taffybar.Widget.SNITray
Description
Documentation
sniTrayNewFromHost :: Host -> TaffyIO Widget Source #
Build a new StatusNotifierItem tray that will share a host with any other trays that are constructed automatically
sniTrayNew :: TaffyIO Widget Source #
The simplest way to build a new StatusNotifierItem tray
sniTrayThatStartsWatcherEvenThoughThisIsABadWayToDoIt :: TaffyIO Widget Source #
Build a new StatusNotifierItem tray that also starts its own watcher, without depending on status-notifier-icon. This will not register applets started before the watcher is started.